---
name: Bug report
about: Report a bug
labels: issue::type::bug
---

<!-- Remove this warning before posting the issue -->

⚠️ If you're not sure whether your problem is a bug, please ask a question in [Discussions][Discussions] instead.

<!-- Make sure you already checked the existing documentation and mark all the checks -->

- [ ] I've read the [FAQ][FAQ]
- [ ] I've read the [Support Policy][Support Policy]
- [ ] I've already searched similar [issues][Issues] and [discussions][Discussions]
- [ ] I've already updated to the most recent supported [release][Releases] (either Stable or Nightly)

[Issues]: https://github.com/robotology/gym-ignition/issues
[Releases]: https://github.com/robotology/gym-ignition/releases
[FAQ]: https://robotology.github.io/gym-ignition/master/info/faq.html
[Discussions]: https://github.com/robotology/gym-ignition/discussions
[Support Policy]: https://robotology.github.io/gym-ignition/master/installation/support_policy.html
    
## Description:

A clear and concise description of the bug and what should be the expected behavior.

## Steps to reproduce

1.
1.
1.

or

```python
# Insert some code
```

## Additional context

<!-- Screenshots, console logs, backtraces, ... -->

<details>
<summary>Title</summary>

Content

</details>

## Environment

- OS: <!-- Insert the distribution, e.g. Ubuntu 20.04 -->
- GPU: <!-- Insert your GPU, e.g. Intel XXX integrated -->    
- Python: <!-- Insert the active Python version and provider, e.g. 3.8.X from virtualenv -->
- Version: <!-- Insert the installed version of gym-ignition and scenario, e.g. v1.2.0 -->
- Channel:
  - [ ] Stable
  - [ ] Nightly
- Installation type:
  - [ ] User
  - [ ] Developer
